@@ -23,7 +23,7 @@
 
 #include <libglom/data_structure/layout/layoutgroup.h>
 #include <libglom/data_structure/layout/layoutitem_field.h>
-#include <map>
+#include <unordered_map>
 
 namespace Glom
 {
@@ -39,10 +39,10 @@ class LayoutItem_GroupBy : public LayoutGroup
 public:
 
   LayoutItem_GroupBy();
-  LayoutItem_GroupBy(const LayoutItem_GroupBy& src);
-  LayoutItem_GroupBy(LayoutItem_GroupBy&& src) = delete;
-  LayoutItem_GroupBy& operator=(const LayoutItem_GroupBy& src);
-  LayoutItem_GroupBy& operator=(LayoutItem_GroupBy&& src) = delete;
+  LayoutItem_GroupBy(const LayoutItem_GroupBy& src) = default;
+  LayoutItem_GroupBy(LayoutItem_GroupBy&& src) = default;
+  LayoutItem_GroupBy& operator=(const LayoutItem_GroupBy& src) = default;
+  LayoutItem_GroupBy& operator=(LayoutItem_GroupBy&& src) = default;
   ~LayoutItem_GroupBy() override;
 
   LayoutItem* clone() const override;
