@@ -30,11 +30,11 @@ class NumericFormat
 {
 public:
   NumericFormat();
-  NumericFormat(const NumericFormat& src);
-  NumericFormat(NumericFormat&& src) = delete;
+  NumericFormat(const NumericFormat& src) = default;
+  NumericFormat(NumericFormat&& src) = default;
 
-  NumericFormat& operator=(const NumericFormat& src);
-  NumericFormat& operator=(NumericFormat&& src) = delete;
+  NumericFormat& operator=(const NumericFormat& src) = default;
+  NumericFormat& operator=(NumericFormat&& src) = default;
 
   bool operator==(const NumericFormat& src) const;
   bool operator!=(const NumericFormat& src) const;
